Deployments
===========
|
A deployment is a group of identical engine instances deployed within an environment that defines the
StreamSets engine type, version, and configuration to use. You can deploy and launch multiple instances
of the configured engine.

For more details, refer to the `StreamSets Platform Documentation <https://docs.streamsets.com/portal/#platform-controlhub/controlhub/UserGuide/Deployments/Deployments_title.html>`_.

.. toctree::
   :maxdepth: 3
   :hidden:

   self_managed_deployments
   ec2_deployments
   azure_vm_deployments
   gce_deployments
   kubernetes_deployments
